@@ -3,45 +3,42 @@ package App::Netdisco::Web::Plugin;
 use Dancer ':syntax';
 use Dancer::Plugin;
 
-use Path::Class 'dir';
-
 set(
   '_additional_css'         => [],
   '_additional_javascript'  => [],
   '_extra_device_port_cols' => [],
-  '_extra_device_details'   => [],
   '_navbar_items' => [],
   '_search_tabs'  => [],
   '_device_tabs'  => [],
   '_admin_tasks'  => {},
-  '_admin_order'  => [],
   '_reports_menu' => {},
   '_reports' => {},
-  '_report_order' => [qw/Device Port IP Node VLAN Network Wireless/, 'My Reports'],
+  '_report_order' => [qw/Device Port Node VLAN Network Wireless/],
 );
 
 # this is what Dancer::Template::TemplateToolkit does by default
-config->{engines}->{netdisco_template_toolkit}->{INCLUDE_PATH} ||= [ setting('views') ];
+config->{engines}->{template_toolkit}->{INCLUDE_PATH} ||= [ setting('views') ];
 
 register 'register_template_path' => sub {
   my ($self, $path) = plugin_args(@_);
 
-  if (!$path) {
+  if (!length $path) {
       return error "bad template path to register_template_paths";
   }
 
-  unshift @{ config->{engines}->{netdisco_template_toolkit}->{INCLUDE_PATH} },
-       dir($path, 'views')->stringify;
+  unshift
+    @{ config->{engines}->{template_toolkit}->{INCLUDE_PATH} },
+    $path;
 };
 
 sub _register_include {
   my ($type, $plugin) = @_;
 
-  if (!$type) {
+  if (!length $type) {
       return error "bad type to _register_include";
   }
 
-  if (!$plugin) {
+  if (!length $plugin) {
       return error "bad plugin name to register_$type";
   }
 
@@ -63,7 +60,7 @@ register 'register_device_port_column' => sub {
   $config->{default} ||= '';
   $config->{position} ||= 'right';
 
-  if (!$config->{name} or !$config->{label}) {
+  if (!length $config->{name} or !length $config->{label}) {
       return error "bad config to register_device_port_column";
   }
 
@@ -77,29 +74,12 @@ register 'register_device_port_column' => sub {
   push @{ setting('_extra_device_port_cols') }, $config;
 };
 
-register 'register_device_details' => sub {
-  my ($self, $config) = plugin_args(@_);
-
-  if (!$config->{name} or !$config->{label}) {
-      return error "bad config to register_device_details";
-  }
-
-  foreach my $item (@{ setting('_extra_device_details') }) {
-      if ($item->{name} eq $config->{name}) {
-          $item = $config;
-          return;
-      }
-  }
-
-  push @{ setting('_extra_device_details') }, $config;
-};
-
 register 'register_navbar_item' => sub {
   my ($self, $config) = plugin_args(@_);
 
-  if (!$config->{tag}
-      or !$config->{path}
-      or !$config->{label}) {
+  if (!length $config->{tag}
+      or !length $config->{path}
+      or !length $config->{label}) {
 
       return error "bad config to register_navbar_item";
   }
@@ -117,13 +97,12 @@ register 'register_navbar_item' => sub {
 register 'register_admin_task' => sub {
   my ($self, $config) = plugin_args(@_);
 
-  if (!$config->{tag}
-      or !$config->{label}) {
+  if (!length $config->{tag}
+      or !length $config->{label}) {
 
       return error "bad config to register_admin_task";
   }
 
-  push @{ setting('_admin_order') }, $config->{tag};
   setting('_admin_tasks')->{ $config->{tag} } = $config;
 };
 
@@ -131,8 +110,8 @@ sub _register_tab {
   my ($nav, $config) = @_;
   my $stash = setting("_${nav}_tabs");
 
-  if (!$config->{tag}
-      or !$config->{label}) {
+  if (!length $config->{tag}
+      or !length $config->{label}) {
 
       return error "bad config to register_${nav}_item";
   }
@@ -161,31 +140,23 @@ register 'register_report' => sub {
   my ($self, $config) = plugin_args(@_);
   my @categories = @{ setting('_report_order') };
 
-  if (!$config->{category}
-      or !$config->{tag}
-      or !$config->{label}
+  if (!length $config->{category}
+      or !length $config->{tag}
+      or !length $config->{label}
       or 0 == scalar grep {$config->{category} eq $_} @categories) {
 
       return error "bad config to register_report";
   }
 
-  if (0 == scalar grep {$_ eq $config->{tag}}
-                       @{setting('_reports_menu')->{ $config->{category} }}) {
-      push @{setting('_reports_menu')->{ $config->{category} }}, $config->{tag};
-  }
-
-  foreach my $tag (@{setting('_reports_menu')->{ $config->{category} }}) {
-      if ($config->{tag} eq $tag) {
-          setting('_reports')->{$tag} = $config;
-
-          foreach my $rconfig (@{setting('reports')}) {
-              if ($rconfig->{tag} eq $tag) {
-                  setting('_reports')->{$tag}->{'rconfig'} = $rconfig;
-                  last;
-              }
-          }
+  foreach my $item (@{setting('_reports_menu')->{ $config->{category} }}) {
+      if ($item eq $config->{tag}) {
+          setting('_reports')->{$config->{tag}} = $config;
+          return;
       }
   }
+
+  push @{setting('_reports_menu')->{ $config->{category} }}, $config->{tag};
+  setting('_reports')->{$config->{tag}} = $config;
 };
 
 register_plugin;
@@ -224,17 +195,12 @@ Additional Device Port Columns
 
 =item *
 
-Additional Device Details
-
-=item *
-
 Admin Menu function (job control, manual topology, pseudo devices)
 
 =back
 
 This document explains how to configure which plugins are loaded. See
-L<App::Netdisco::Manual::WritingWebPlugins> if you want to develop new
-plugins.
+L<App::Netdisco::Manual::WritingPlugins> if you want to develop new plugins.
 
 =head1 Application Configuration
 
